import { TPrimitives } from "./types";
/**
 * Add metadata to a value to store it as json, it also supports Map, Set, Arrays,
 * Returns a new object which is a clone of the original object with metadata
 * @template {TValue} The type of the value to format
 * @template {TStringify} If the value should be stringified
 * @param {TValue} value The value to format
 * @param {{ stringify: TStringify }} { stringify: boolean } If the value should be stringified
 */
export declare const formatToStore: <TValue, TStringify extends boolean = false>(value: TValue, { stringify, validator, excludeTypes, excludeKeys, sortKeys, }?: {
    stringify?: TStringify;
    excludeTypes?: TPrimitives[] | Set<TPrimitives>;
    excludeKeys?: string[] | Set<string>;
    sortKeys?: boolean | ((a: string, b: string) => number);
    /**
     * Returns true if the value should be included in the stringified version,
     * if provided it will override the default validator and the excludesTypes and excludeKeys
     */
    validator?: ({ obj, key, value, }: {
        obj: unknown;
        key: string;
        value: unknown;
    }) => boolean | undefined;
}) => TStringify extends true ? string : unknown;
